@@ -1,14 +1,7 @@
-#!/usr/bin/env python3
-# --------------------------------------------------------------------------------------
 # SPDX-FileCopyrightText: 2021 Magenta ApS <https://magenta.dk>
 # SPDX-License-Identifier: MPL-2.0
-# --------------------------------------------------------------------------------------
-# --------------------------------------------------------------------------------------
-# Imports
-# --------------------------------------------------------------------------------------
 from datetime import datetime
 from typing import Any
-from typing import Dict
 
 from dateutil.parser import isoparse
 from pydantic import BaseModel
@@ -23,20 +16,12 @@ except ImportError:  # pragma: no cover
     from backports import zoneinfo  # type: ignore
 
 
-# --------------------------------------------------------------------------------------
-# Globals
-# --------------------------------------------------------------------------------------
-
 # TODO: Perhaps it's worth reading from e.g. env vars here
 DEFAULT_TZ = zoneinfo.ZoneInfo("Europe/Copenhagen")
 
 POS_INF = "infinity"
 NEG_INF = "-infinity"
 
-# --------------------------------------------------------------------------------------
-# Base models
-# --------------------------------------------------------------------------------------
-
 
 class RABase(BaseModel):
     """Base model for RA data models."""
@@ -59,15 +44,12 @@ class RABase(BaseModel):
         extra = Extra.forbid
 
     @root_validator(pre=True)
-    def remove_integration_data(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+    def remove_integration_data(cls, values: dict[str, Any]) -> dict[str, Any]:
         values.pop("integration_data", None)
         values.pop("integrationsdata", None)
         return values
 
 
-# --------------------------------------------------------------------------------------
-# Base utils
-# --------------------------------------------------------------------------------------
 def tz_isodate(dt: Any) -> datetime:
     """Attempts to parse an incoming value as a timezone aware datetime.
 
