@@ -1,20 +1,10 @@
-#!/usr/bin/env python3
-# --------------------------------------------------------------------------------------
 # SPDX-FileCopyrightText: 2021 Magenta ApS <https://magenta.dk>
 # SPDX-License-Identifier: MPL-2.0
-# --------------------------------------------------------------------------------------
-# --------------------------------------------------------------------------------------
-# Imports
-# --------------------------------------------------------------------------------------
+from collections.abc import Callable
+from collections.abc import Iterator
 from datetime import datetime
 from typing import Any
-from typing import Callable
-from typing import Dict
-from typing import Iterator
-from typing import List
 from typing import Literal
-from typing import Optional
-from typing import Union
 from uuid import UUID
 from uuid import uuid4
 
@@ -35,10 +25,6 @@ except ImportError:  # pragma: no cover
 
 UTC = zoneinfo.ZoneInfo("UTC")
 
-# --------------------------------------------------------------------------------------
-# LoRaBase
-# --------------------------------------------------------------------------------------
-
 
 class LoraBase(RABase):
     """Base model for LoRa data models.
@@ -61,11 +47,11 @@ class LoraBase(RABase):
     # However, the beta version of default_factory is still unstable and prone to
     # side-effects.
     @validator("uuid", pre=True, always=True)
-    def set_uuid(cls, _uuid: Optional[UUID]) -> UUID:
+    def set_uuid(cls, _uuid: UUID | None) -> UUID:
         return _uuid or uuid4()
 
     @validator("object_type", pre=True, check_fields=False)
-    def lower_object_type(cls, object_type: Optional[Any]) -> Any:
+    def lower_object_type(cls, object_type: Any | None) -> Any:
         """
         Lower the object_type before validating equality with the literal, as some LoRa
         databases define the capitalised value, while others do not.
@@ -75,11 +61,6 @@ class LoraBase(RABase):
         return object_type
 
 
-# --------------------------------------------------------------------------------------
-# Infinite Datetime
-# --------------------------------------------------------------------------------------
-
-
 class InfiniteDatetime(str):
     # Inspired by
     # https://pydantic-docs.helpmanual.io/usage/types/#classes-with-__get_validators__
@@ -90,7 +71,7 @@ class InfiniteDatetime(str):
     If a new object is desired, please use the from_value class method."""
 
     @classmethod
-    def from_value(cls, value: Union[str, datetime]) -> "InfiniteDatetime":
+    def from_value(cls, value: str | datetime) -> "InfiniteDatetime":
         return cls.validate(value)
 
     @classmethod
@@ -178,11 +159,6 @@ class InfiniteDatetime(str):
         return self.__gt__(other) or self.__eq__(other)
 
 
-# --------------------------------------------------------------------------------------
-# Shared models
-# --------------------------------------------------------------------------------------
-
-
 class EffectiveTime(RABase):
     """
     The effective time of a given object in LoRa.
@@ -191,24 +167,24 @@ class EffectiveTime(RABase):
     from_date: InfiniteDatetime = Field(
         alias="from", description="Start of the effective time interval."
     )
-    from_included: Optional[bool] = Field(
+    from_included: bool | None = Field(
         description="Whether from_date is included in the interval."
     )
     to_date: InfiniteDatetime = Field(
         alias="to", description="End of the effective time interval."
     )
-    to_included: Optional[bool] = Field(
+    to_included: bool | None = Field(
         description="Whether to_date is included in the interval."
     )
-    actor_type: Optional[str] = Field(
+    actor_type: str | None = Field(
         alias="aktoertypekode", description="Actor type indicator, e.g. Bruger"
     )
-    actor_ref: Optional[UUID] = Field(
+    actor_ref: UUID | None = Field(
         alias="aktoerref", description="Actor UUID reference."
     )
 
     @root_validator
-    def check_from_lt_to(cls, values: Dict[str, Any]) -> Dict[str, Any]:
+    def check_from_lt_to(cls, values: dict[str, Any]) -> dict[str, Any]:
         from_date, to_date = values.get("from_date"), values.get("to_date")
         # Mypy complains here about unsupported use of operators due to Nones,
         # but we catch those with if all...
@@ -235,7 +211,7 @@ class FacetProperties(RABase):
     """
 
     user_key: str = Field(alias="brugervendtnoegle", description="Short, unique key.")
-    description: Optional[str] = Field(
+    description: str | None = Field(
         alias="beskrivelse", description="The facet description."
     )
     effective_time: EffectiveTime = Field(
@@ -248,7 +224,7 @@ class FacetAttributes(RABase):
     Attributes of a given LoRa facet.
     """
 
-    properties: List[FacetProperties] = Field(
+    properties: list[FacetProperties] = Field(
         alias="facetegenskaber",
         min_items=1,
         max_items=1,
@@ -279,7 +255,7 @@ class FacetStates(RABase):
     States of a given LoRa facet.
     """
 
-    published_state: List[Published] = Field(
+    published_state: list[Published] = Field(
         alias="facetpubliceret",
         min_items=1,
         max_items=1,
@@ -301,9 +277,9 @@ class Relation(RABase):
 
 
 def get_relations(
-    uuids: Union[None, UUID, List[UUID]] = None,
-    effective_time: Optional[EffectiveTime] = None,
-) -> Optional[List[Relation]]:
+    uuids: None | UUID | list[UUID] = None,
+    effective_time: EffectiveTime | None = None,
+) -> list[Relation] | None:
     """Returns a list of `Relation`s obtained from UUIDs or None if `uuids=None`"""
 
     if uuids is None or effective_time is None:
@@ -388,13 +364,13 @@ class FacetRelations(RABase):
     Facet relations given by responsible objects.
     """
 
-    responsible: List[Responsible] = Field(
+    responsible: list[Responsible] = Field(
         alias="ansvarlig",
         min_items=1,
         max_items=1,
         description="The responsible object.",
     )
-    parent: Optional[List[ParentClassification]] = Field(
+    parent: list[ParentClassification] | None = Field(
         alias="facettilhoerer",
         min_items=1,
         max_items=1,
@@ -406,16 +382,16 @@ class ITSystemProperties(RABase):
     """Properties for an ITSystem attribute."""
 
     user_key: str = Field(alias="brugervendtnoegle", description="Short, unique key.")
-    effective_time: Optional[EffectiveTime] = Field(
+    effective_time: EffectiveTime | None = Field(
         alias="virkning", description="Effective time of the properties."
     )
-    name: Optional[str] = Field(
+    name: str | None = Field(
         alias="itsystemnavn", description="Official name for the ITSystem."
     )
-    type: Optional[str] = Field(
+    type: str | None = Field(
         alias="itsystemtype", description="Short description of the type of properties."
     )
-    configuration_ref: Optional[List[str]] = Field(
+    configuration_ref: list[str] | None = Field(
         alias="konfigurationsreference", description="One of ['Ja', 'Nej', 'Ved ikke']."
     )
 
@@ -425,7 +401,7 @@ class ITSystemAttributes(RABase):
 
     Referencing a list of `ITSystemProperties`."""
 
-    properties: List[ITSystemProperties] = Field(
+    properties: list[ITSystemProperties] = Field(
         alias="itsystemegenskaber", min_items=1, max_items=1
     )
 
@@ -449,7 +425,7 @@ class ITSystemStates(RABase):
     Referencing a list of `ITSystemValidState`
     """
 
-    valid_state: List[ITSystemValidState] = Field(
+    valid_state: list[ITSystemValidState] = Field(
         alias="itsystemgyldighed", min_items=1, max_items=1
     )
 
@@ -462,60 +438,60 @@ class ITSystemRelations(RABase):
     # effetive_time; thus they share type here.
 
     # zero2one relation
-    belongs_to: Optional[List[Relation]] = Field(
+    belongs_to: list[Relation] | None = Field(
         alias="tilhoerer",
         min_items=1,
         max_items=1,
         description="Reference to a organisation the ITSystem belongs to",
     )
     # zero2many relations
-    affiliated_orgs: Optional[List[Relation]] = Field(
+    affiliated_orgs: list[Relation] | None = Field(
         alias="tilknyttedeorganisationer",
         description="Reference to affiliated organisations",
         min_items=1,
     )
-    affiliated_units: Optional[List[Relation]] = Field(
+    affiliated_units: list[Relation] | None = Field(
         alias="tilknyttedeenheder",
         description="Reference to affiliated organisation units",
         min_items=1,
     )
-    affiliated_functions: Optional[List[Relation]] = Field(
+    affiliated_functions: list[Relation] | None = Field(
         alias="tilknyttedefunktioner",
         description="Reference to affiliated organisation functions",
         min_items=1,
     )
-    affiliated_users: Optional[List[Relation]] = Field(
+    affiliated_users: list[Relation] | None = Field(
         alias="tilknyttedebrugere",
         description="Reference to affiliated users",
         min_items=1,
     )
-    affiliated_interests: Optional[List[Relation]] = Field(
+    affiliated_interests: list[Relation] | None = Field(
         alias="tilknyttedeinteressefaelleskaber",
         description="Reference to affiliated common interest",
         min_items=1,
     )
-    affiliated_itsystems: Optional[List[Relation]] = Field(
+    affiliated_itsystems: list[Relation] | None = Field(
         alias="tilknyttedeitsystemer",
         description="Reference to affiliated ITSystems",
         min_items=1,
     )
-    affiliated_persons: Optional[List[Relation]] = Field(
+    affiliated_persons: list[Relation] | None = Field(
         alias="tilknyttedepersoner",
         description="Reference to affiliated persons",
         min_items=1,
     )
-    addresses: Optional[List[Relation]] = Field(
+    addresses: list[Relation] | None = Field(
         alias="adresser",
         description="Affiliated addresses, like URL",
         min_items=1,
     )
     # the two following are type Klasse
-    system_types: Optional[List[Relation]] = Field(
+    system_types: list[Relation] | None = Field(
         alias="systemtyper",
         description="Reference to affiliated systemtypes, like STORM",
         min_items=1,
     )
-    tasks: Optional[List[Relation]] = Field(
+    tasks: list[Relation] | None = Field(
         alias="opgaver",
         description="Reference to affiliated tasks, like FORM",
         min_items=1,
@@ -529,14 +505,12 @@ class KlasseProperties(RABase):
 
     user_key: str = Field(alias="brugervendtnoegle", description="Short, unique key.")
     title: str = Field(alias="titel", description="Title of the LoRa Klasse.")
-    scope: Optional[str] = Field(
-        alias="omfang", description="Scope of the LoRa Klasse."
-    )
+    scope: str | None = Field(alias="omfang", description="Scope of the LoRa Klasse.")
     effective_time: EffectiveTime = Field(
         alias="virkning", description="Effective time of the properties."
     )
-    example: Optional[str] = Field(alias="eksempel", description="Example usage.")
-    description: Optional[str] = Field(
+    example: str | None = Field(alias="eksempel", description="Example usage.")
+    description: str | None = Field(
         alias="beskrivelse", description="Description of the Klasse."
     )
 
@@ -546,22 +520,22 @@ class KlasseRelations(RABase):
     Klasse relations given by responsible objects and facet references.
     """
 
-    responsible: List[Responsible] = Field(
+    responsible: list[Responsible] = Field(
         alias="ansvarlig",
         min_items=1,
         max_items=1,
         description="The responsible object.",
     )
-    facet: List[FacetRef] = Field(
+    facet: list[FacetRef] = Field(
         min_items=1, max_items=1, description="Facet reference."
     )
-    parent: Optional[List[ClassRef]] = Field(
+    parent: list[ClassRef] | None = Field(
         alias="overordnetklasse",
         min_items=1,
         max_items=1,
         description="The parent class object.",
     )
-    owner: Optional[List[OwnerRef]] = Field(
+    owner: list[OwnerRef] | None = Field(
         alias="ejer",
         min_items=1,
         max_items=1,
@@ -574,7 +548,7 @@ class KlasseAttributes(RABase):
     LoRa Klasse attributes.
     """
 
-    properties: List[KlasseProperties] = Field(
+    properties: list[KlasseProperties] = Field(
         alias="klasseegenskaber",
         min_items=1,
         max_items=1,
@@ -587,7 +561,7 @@ class KlasseStates(RABase):
     Published state of a LoRa Klasse.
     """
 
-    published_state: List[Published] = Field(
+    published_state: list[Published] = Field(
         alias="klassepubliceret",
         min_items=1,
         max_items=1,
@@ -614,7 +588,7 @@ class OrganisationAttributes(RABase):
     LoRa organisation attributes.
     """
 
-    properties: List[OrganisationProperties] = Field(
+    properties: list[OrganisationProperties] = Field(
         alias="organisationegenskaber",
         min_items=1,
         max_items=1,
@@ -642,7 +616,7 @@ class OrganisationStates(RABase):
     Organisation validity as given by OrganisationValidState.
     """
 
-    valid_state: List[OrganisationValidState] = Field(
+    valid_state: list[OrganisationValidState] = Field(
         alias="organisationgyldighed",
         min_items=1,
         max_items=1,
@@ -655,7 +629,7 @@ class OrganisationRelations(RABase):
     Organisation relations given by an authority object.
     """
 
-    authority: List[Authority] = Field(
+    authority: list[Authority] = Field(
         alias="myndighed",
         min_items=1,
         max_items=1,
@@ -667,6 +641,6 @@ class RegistrationTime(BaseModel):
     timestamp_datetime: InfiniteDatetime = Field(
         alias="tidsstempeldatotid", description="The registration timestamp"
     )
-    limit_indicator: Optional[bool] = Field(
+    limit_indicator: bool | None = Field(
         alias="graenseindikator", description="The registration limit indicator"
     )
